@@ -48,13 +48,13 @@ struct _ColourGUI {
 static GHashTable *colourgui_being_edited = NULL;
 
 static void colourgui_set_colour_widget(GtkBuilder *builder,
-        const char *widget_name, GdkColor *colour, gboolean ignore)
+        const char *widget_name, COLOUR_T *colour, gboolean ignore)
 {
 #if HAVE_COLORMAP
     static GdkColormap *colour_map = NULL;
 #endif
     GtkWidget *widget;
-    
+
     if (!colour)
         return;
 #if HAVE_COLORMAP
@@ -64,12 +64,10 @@ static void colourgui_set_colour_widget(GtkBuilder *builder,
                 TRUE, TRUE));
 #endif
     widget = GTK_WIDGET(gtk_builder_get_object(builder, widget_name));
-    /* gtk_color_button_set_color doesn't seem to cause a change signal so
+    /* Setting a colour doesn't seem to cause a change signal so
      * explicitly raise one if necessary */
     capplet_ignore_changes = TRUE;
-    gtk_color_button_set_color(
-            GTK_COLOR_BUTTON(widget),
-            colour);
+    COLOUR_BUTTON_SET(widget, colour);
     capplet_ignore_changes = FALSE;
     if (!ignore)
         g_signal_emit_by_name(widget, "color-set");
@@ -91,11 +89,25 @@ static void colourgui_set_cursor_colour_widget(GtkBuilder *builder,
             colour_scheme_get_cursor_colour(colour_scheme, FALSE), ignore);
 }
 
+static void colourgui_set_bold_colour_widget(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore)
+{
+    colourgui_set_colour_widget(builder, "bold_colour",
+            colour_scheme_get_bold_colour(colour_scheme, FALSE), ignore);
+}
+
+static void colourgui_set_dim_colour_widget(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore)
+{
+    colourgui_set_colour_widget(builder, "dim_colour",
+            colour_scheme_get_dim_colour(colour_scheme, FALSE), ignore);
+}
+
 static void colourgui_set_all_palette_widgets(GtkBuilder *builder,
         Options *colour_scheme, gboolean ignore)
 {
     int n;
-    GdkColor *palette = colour_scheme_get_palette(colour_scheme);
+    COLOUR_T *palette = colour_scheme_get_palette(colour_scheme);
 
     g_return_if_fail(palette);
     for (n = 0; n < 24; ++n)
@@ -178,6 +190,22 @@ static void colourgui_set_cursor_shading(GtkBuilder *builder)
                     gtk_builder_get_object(builder, "set_cursor_colour"))));
 }
 
+static void colourgui_set_bold_shading(GtkBuilder *builder)
+{
+    gtk_widget_set_sensitive(
+            GTK_WIDGET(gtk_builder_get_object(builder, "bold_colour")),
+            gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+                    gtk_builder_get_object(builder, "set_bold_colour"))));
+}
+
+static void colourgui_set_dim_shading(GtkBuilder *builder)
+{
+    gtk_widget_set_sensitive(
+            GTK_WIDGET(gtk_builder_get_object(builder, "dim_colour")),
+            gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(
+                    gtk_builder_get_object(builder, "set_dim_colour"))));
+}
+
 static void colourgui_set_fgbg_toggle(GtkBuilder *builder,
         Options *colour_scheme, gboolean ignore)
 {
@@ -205,13 +233,13 @@ static void colourgui_set_fgbg_track_toggle(GtkBuilder *builder,
                     "set_fgbg")))
             && colour_scheme_get_palette_size(colour_scheme))
     {
-        GdkColor *palette = colour_scheme_get_palette(colour_scheme);
-        GdkColor *fg = colour_scheme_get_foreground_colour(colour_scheme, TRUE);
-        GdkColor *bg = colour_scheme_get_background_colour(colour_scheme, TRUE);
+        COLOUR_T *palette = colour_scheme_get_palette(colour_scheme);
+        COLOUR_T *fg = colour_scheme_get_foreground_colour(colour_scheme, TRUE);
+        COLOUR_T *bg = colour_scheme_get_background_colour(colour_scheme, TRUE);
 
         if (fg && bg
-                && gdk_color_equal(&palette[0], fg)
-                && gdk_color_equal(&palette[7], bg))
+                && COLOUR_EQUAL(&palette[0], fg)
+                && COLOUR_EQUAL(&palette[7], bg))
         {
             track = TRUE;
         }
@@ -227,7 +255,7 @@ static void colourgui_set_fgbg_track_toggle(GtkBuilder *builder,
 static void colourgui_set_palette_toggles(GtkBuilder *builder,
         Options *colour_scheme, gboolean ignore)
 {
-    int ps = colour_scheme_get_palette_size(colour_scheme); 
+    int ps = colour_scheme_get_palette_size(colour_scheme);
     GtkToggleButton *ucp =
         GTK_TOGGLE_BUTTON(gtk_builder_get_object(builder,
                 "use_custom_colours"));
@@ -256,18 +284,40 @@ static void colourgui_set_palette_toggles(GtkBuilder *builder,
     capplet_ignore_changes = FALSE;
 }
 
-static void colourgui_set_cursor_toggle(GtkBuilder *builder,
-        Options *colour_scheme, gboolean ignore)
+static void colourgui_set_named_toggle(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore,
+        const char *opt_name, const char *widget_name)
 {
-    char *cc = options_lookup_string(colour_scheme, "cursor");
+    char *ov = options_lookup_string(colour_scheme, opt_name);
 
     capplet_ignore_changes = ignore;
     gtk_toggle_button_set_active(
             GTK_TOGGLE_BUTTON(gtk_builder_get_object(builder,
-                    "set_cursor_colour")),
-            cc != NULL);
+                    widget_name)),
+            ov != NULL);
     capplet_ignore_changes = FALSE;
-    g_free(cc);
+    g_free(ov);
+}
+
+inline static void colourgui_set_cursor_toggle(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore)
+{
+    colourgui_set_named_toggle(builder, colour_scheme, ignore,
+            "cursor", "set_cursor_colour");
+}
+
+inline static void colourgui_set_bold_toggle(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore)
+{
+    colourgui_set_named_toggle(builder, colour_scheme, ignore,
+            "bold", "set_bold_colour");
+}
+
+inline static void colourgui_set_dim_toggle(GtkBuilder *builder,
+        Options *colour_scheme, gboolean ignore)
+{
+    colourgui_set_named_toggle(builder, colour_scheme, ignore,
+            "dim", "set_dim_colour");
 }
 
 static void colourgui_set_all_toggles(GtkBuilder *builder,
@@ -277,6 +327,8 @@ static void colourgui_set_all_toggles(GtkBuilder *builder,
     colourgui_set_fgbg_track_toggle(builder, colour_scheme, ignore);
     colourgui_set_palette_toggles(builder, colour_scheme, ignore);
     colourgui_set_cursor_toggle(builder, colour_scheme, ignore);
+    colourgui_set_bold_toggle(builder, colour_scheme, ignore);
+    colourgui_set_dim_toggle(builder, colour_scheme, ignore);
 }
 
 static void colourgui_set_all_shading(GtkBuilder *builder)
@@ -285,6 +337,8 @@ static void colourgui_set_all_shading(GtkBuilder *builder)
     colourgui_set_fgbg_shading(builder);
     colourgui_set_fgbg_track_shading(builder);
     colourgui_set_cursor_shading(builder);
+    colourgui_set_bold_shading(builder);
+    colourgui_set_dim_shading(builder);
 }
 
 static void colourgui_fill_in_dialog(ColourGUI * cg, gboolean ignore)
@@ -297,6 +351,8 @@ static void colourgui_fill_in_dialog(ColourGUI * cg, gboolean ignore)
     colourgui_set_all_palette_widgets(builder, colour_scheme, ignore);
     colourgui_set_fgbg_colour_widgets(builder, colour_scheme, ignore);
     colourgui_set_cursor_colour_widget(builder, colour_scheme, ignore);
+    colourgui_set_bold_colour_widget(builder, colour_scheme, ignore);
+    colourgui_set_dim_colour_widget(builder, colour_scheme, ignore);
 }
 
 static void colourgui_revert(ColourGUI *cg)
@@ -311,6 +367,7 @@ static void colourgui_revert(ColourGUI *cg)
 
 void on_Colour_Editor_destroy(GtkWidget *widget, ColourGUI * cg)
 {
+    (void) widget;
     if (cg->ignore_destroy)
     {
         return;
@@ -324,6 +381,7 @@ void on_Colour_Editor_destroy(GtkWidget *widget, ColourGUI * cg)
 
 void on_Colour_Editor_response(GtkWidget *widget, gint response, ColourGUI * cg)
 {
+    (void) widget;
     if (response == 1)
         colourgui_revert(cg);
     else
@@ -332,15 +390,15 @@ void on_Colour_Editor_response(GtkWidget *widget, gint response, ColourGUI * cg)
 
 void on_Colour_Editor_close(GtkWidget *widget, ColourGUI * cg)
 {
+    (void) widget;
     colourgui_delete(cg);
 }
 
-static const char *colourgui_name_colour(const GdkColor *colour)
+static const char *colourgui_name_colour(const COLOUR_T *colour)
 {
     static char colour_name[16];
 
-    sprintf(colour_name, "#%04hx%04hx%04hx",
-            colour->red, colour->green, colour->blue);
+    COLOUR_SPRINTF(colour_name, colour);
     return colour_name;
 }
 
@@ -350,10 +408,10 @@ static const char *colourgui_read_colour_widget(ColourGUI *cg,
     GtkColorButton *button =
             GTK_COLOR_BUTTON(gtk_builder_get_object(cg->capp.builder,
                     widget_name));
-    GdkColor colour;
+    COLOUR_T colour;
 
     g_return_val_if_fail(button, NULL);
-    gtk_color_button_get_color(button, &colour);
+    COLOUR_BUTTON_GET(button, &colour);
     return colourgui_name_colour(&colour);
 }
 
@@ -381,10 +439,10 @@ static void colourgui_set_colour_option_from_widget(ColourGUI *cg,
         colourgui_set_colour_option_from_widget(cg, #name "_colour", \
         #name, colour_scheme_set_ ## name ## _colour)
 
-void on_color_set(GtkColorButton *button, ColourGUI * cg) 
+void on_color_set(GtkColorButton *button, ColourGUI * cg)
 {
     const char *widget_name;
-    GdkColor colour;
+    COLOUR_T colour;
     const char *colour_name;
     const char *option_name = NULL;
     char dyn_opt_nm[8];
@@ -396,7 +454,7 @@ void on_color_set(GtkColorButton *button, ColourGUI * cg)
     }
     widget_name = gtk_buildable_get_name(GTK_BUILDABLE(button));
     g_return_if_fail(widget_name);
-    gtk_color_button_get_color(button, &colour);
+    COLOUR_BUTTON_GET(button, &colour);
     colour_name = colourgui_name_colour(&colour);
     if (!strcmp(widget_name, "foreground_colour"))
     {
@@ -413,6 +471,16 @@ void on_color_set(GtkColorButton *button, ColourGUI * cg)
         option_name = "cursor";
         colour_scheme_set_cursor_colour(opts, colour_name);
     }
+    else if (!strcmp(widget_name, "bold_colour"))
+    {
+        option_name = "bold";
+        colour_scheme_set_bold_colour(opts, colour_name);
+    }
+    else if (!strcmp(widget_name, "dim_colour"))
+    {
+        option_name = "dim";
+        colour_scheme_set_dim_colour(opts, colour_name);
+    }
     else if (!strncmp(widget_name, "palette", 7) && strlen(widget_name) == 10)
     {
         int row = widget_name[7] - '0';
@@ -478,12 +546,11 @@ void on_set_fgbg_toggled(GtkToggleButton *button, ColourGUI * cg)
 static void mirror_colour(ColourGUI *cg, const char *source_widget_name,
         const char *target_widget, const char *target_option)
 {
-    GdkColor colour;
+    COLOUR_T colour;
     const char *colour_name;
 
-    gtk_color_button_get_color(
-        GTK_COLOR_BUTTON(gtk_builder_get_object(cg->capp.builder,
-                source_widget_name)),
+    COLOUR_BUTTON_GET(gtk_builder_get_object(cg->capp.builder,
+                source_widget_name),
         &colour);
     colour_name = colourgui_name_colour(&colour);
     colourgui_set_colour_widget(cg->capp.builder, target_widget, &colour, TRUE);
@@ -508,6 +575,7 @@ void on_fgbg_track_palette_toggled(GtkToggleButton *button, ColourGUI * cg)
 
 void on_use_custom_colours_toggled(GtkToggleButton *button, ColourGUI *cg)
 {
+    (void) button;
     gboolean state;
     int old_size;
     int palette_size;
@@ -586,6 +654,36 @@ void on_set_cursor_colour_toggled(GtkToggleButton *button, ColourGUI *cg)
         COLOURGUI_SET_COLOUR_OPTION(cg->capp.options, cursor, NULL);
 }
 
+void on_set_bold_colour_toggled(GtkToggleButton *button, ColourGUI *cg)
+{
+    int state;
+
+    if (capplet_ignore_changes)
+        return;
+
+    colourgui_set_bold_shading(cg->capp.builder);
+    state = gtk_toggle_button_get_active(button);
+    if (state)
+        COLOURGUI_SET_COLOUR_OPTION_FROM_WIDGET(cg, bold);
+    else
+        COLOURGUI_SET_COLOUR_OPTION(cg->capp.options, bold, NULL);
+}
+
+void on_set_dim_colour_toggled(GtkToggleButton *button, ColourGUI *cg)
+{
+    int state;
+
+    if (capplet_ignore_changes)
+        return;
+
+    colourgui_set_dim_shading(cg->capp.builder);
+    state = gtk_toggle_button_get_active(button);
+    if (state)
+        COLOURGUI_SET_COLOUR_OPTION_FROM_WIDGET(cg, dim);
+    else
+        COLOURGUI_SET_COLOUR_OPTION(cg->capp.options, dim, NULL);
+}
+
 void on_palette_size_toggled(GtkToggleButton *button, ColourGUI *cg)
 {
     /* We can ignore a radio button being switched off because we'll get
@@ -619,7 +717,7 @@ ColourGUI *colourgui_open(const char *scheme_name, GdkScreen *scrn)
         gtk_window_present(GTK_WINDOW(cg->widget));
         return cg;
     }
-    
+
     cg = g_new0(ColourGUI, 1);
     cg->scheme_name = g_strdup(scheme_name);
     cg->capp.options = colour_scheme_lookup_and_ref(scheme_name);
@@ -640,7 +738,7 @@ ColourGUI *colourgui_open(const char *scheme_name, GdkScreen *scrn)
     title = g_strdup_printf(_("ROXTerm Colour Scheme \"%s\""), scheme_name);
     gtk_window_set_title(GTK_WINDOW(cg->widget), title);
     g_free(title);
-    
+
     if (!cg->orig_scheme)
     {
         dlg_warning(GTK_WINDOW(cg->widget),
