@@ -32,7 +32,9 @@
 #include "options.h"
 #include "profilegui.h"
 
+#if !VTE_BACKGROUND_DEPRECATED
 #define MANAGE_PREVIEW
+#endif
 
 struct _ProfileGUI {
     CappletData capp;
@@ -111,6 +113,7 @@ void profilegui_check_entries_for_changes(ProfileGUI * pg)
     PG_UPDATE_IF(win_title)
 }
 
+#if !VTE_BACKGROUND_DEPRECATED
 static void profilegui_set_bgimg_shading(ProfileGUI *pg, gboolean sensitive)
 {
     gtk_widget_set_sensitive(profilegui_widget(pg,
@@ -137,6 +140,7 @@ static void profilegui_set_background_shading(ProfileGUI *pg)
     profilegui_set_transparency_shading(pg, !gtk_toggle_button_get_active(
             GTK_TOGGLE_BUTTON(profilegui_widget(pg, "background_type0"))));
 }
+#endif
 
 static void profilegui_set_command_shading(ProfileGUI *pg)
 {
@@ -264,11 +268,20 @@ void on_profile_notebook_switch_page(GtkNotebook * notebook, GtkWidget *page,
     profilegui_check_entries_for_changes(pg);
 }
 
+/* The deprectated background config signal handlers shouldn't be removed
+ * altogether because they're still referenced in the .ui file and would
+ * cause warnings.
+ */
 void on_bgtype_toggled(GtkToggleButton *button, ProfileGUI *pg)
 {
+#if VTE_BACKGROUND_DEPRECATED
+    (void) button;
+    (void) pg;
+#else
     if (gtk_toggle_button_get_active(button))
         profilegui_set_background_shading(pg);
     on_radio_toggled(button, &pg->capp);
+#endif
 }
 
 void on_command_toggled(GtkToggleButton *button, ProfileGUI *pg)
@@ -293,12 +306,6 @@ void on_cell_size_toggled(GtkToggleButton *button, ProfileGUI *pg)
 
 #define PREVIEW_SIZE 160
 
-inline static gboolean pg_image_reportable(ProfileGUI *pg)
-{
-    return (capplet_which_radio_is_selected(
-                profilegui_widget(pg, "background_type1")) == 1);
-}
-
 #ifdef MANAGE_PREVIEW
 static void
 pg_load_preview(GtkFileChooser *chooser, GtkWidget *preview,
@@ -329,28 +336,6 @@ pg_load_preview(GtkFileChooser *chooser, GtkWidget *preview,
     }
     gtk_image_set_from_pixbuf(GTK_IMAGE(preview), pixbuf);
 
-    /* Let's not report file not found any more */
-#if 0
-    if (!pixbuf && filename && filename[0] &&
-            !g_file_test(filename, G_FILE_TEST_IS_DIR))
-    {
-        if (pg_image_reportable(pg))
-        {
-            GtkWidget *tl = gtk_widget_get_toplevel(preview);
-            if (tl && !GTK_WIDGET_TOPLEVEL(tl))
-                tl = NULL;
-            dlg_warning(GTK_WINDOW(tl),
-                    _("Unable to load background image file '%s': %s"),
-                    filename, error ? error->message : _("unknown reason"));
-        }
-        else
-        {
-            g_warning(_("Unable to load background image file '%s': %s"),
-                    filename, error ? error->message : _("unknown reason"));
-        }
-    }
-#endif
-
     if (error)
         g_error_free(error);
     gtk_file_chooser_set_preview_widget_active(chooser, pixbuf != NULL);
@@ -373,6 +358,7 @@ static void on_update_preview(GtkFileChooser *chooser, ProfileGUI *pg)
 }
 #endif
 
+#if !VTE_BACKGROUND_DEPRECATED
 static void profilegui_setup_file_chooser(ProfileGUI *pg)
 {
     GtkFileChooser *chooser =
@@ -429,10 +415,16 @@ static char *get_bgimg_filename(ProfileGUI *pg, GtkFileChooser *chooser)
     capplet_set_string(pg->capp.options, "background_img", new_filename);
     return new_filename;
 }
+#endif
 
 void on_bgimg_chosen(GtkFileChooser *chooser, ProfileGUI *pg)
 {
+#if VTE_BACKGROUND_DEPRECATED
+    (void) chooser;
+    (void) pg;
+#else
     g_free(get_bgimg_filename(pg, chooser));
+#endif
 }
 
 #define DEFAULT_BACKSPACE_BINDING 0
@@ -464,6 +456,7 @@ void on_edit_colour_scheme_clicked(GtkButton *button, ProfileGUI *pg)
     colourgui_open(name, gtk_widget_get_screen(combo));
 }
 
+#if !VTE_BACKGROUND_DEPRECATED
 static char *pg_get_dragged_in_filename(const char *text, gulong length)
 {
     char *first_file = first_file = strstr(text, "\r\n");
@@ -499,6 +492,7 @@ static gboolean bgimg_drag_data_received(GtkWidget *widget,
     g_free(filename);
     return result;
 }
+#endif
 
 static void exit_action_changed(GtkComboBox *combo, ProfileGUI *pg)
 {
@@ -756,15 +750,17 @@ static void profilegui_fill_in_dialog(ProfileGUI * pg)
     capplet_set_boolean_toggle(&pg->capp, "match_plain_files", FALSE);
     capplet_set_spin_button(&pg->capp, "width", 80);
     capplet_set_spin_button(&pg->capp, "height", 24);
-    capplet_set_radio(&pg->capp, "background_type", 0);
     on_cell_size_toggled(GTK_TOGGLE_BUTTON(profilegui_widget(pg, "cell_size")),
             pg);
+#if !VTE_BACKGROUND_DEPRECATED
+    capplet_set_radio(&pg->capp, "background_type", 0);
     profilegui_set_background_shading(pg);
     capplet_set_float_range(&pg->capp, "saturation", 1.0);
     capplet_set_boolean_toggle(&pg->capp, "scroll_background", TRUE);
     val = options_lookup_string_with_default(profile, "background_img", "");
     profilegui_fill_in_file_chooser(pg, val);
     g_free(val);
+#endif
     capplet_set_radio(&pg->capp, "scrollbar_pos", 1);
     capplet_set_spin_button(&pg->capp, "scrollback_lines", 1000);
     capplet_set_boolean_toggle(&pg->capp, "scroll_on_output", FALSE);
@@ -822,8 +818,11 @@ static void profilegui_setup_list_store(ProfileGUI *pg)
 {
     static char const *labels[] = {
             N_("Appearance"), N_("General"), N_("Command"),
-            N_("Net URIs"), N_("File URIs"), N_("Background"), N_("Scrolling"),
-            N_("Keyboard"), N_("Tabs")
+            N_("Net URIs"), N_("File URIs"),
+#if !VTE_BACKGROUND_DEPRECATED
+            N_("Background"),
+#endif
+            N_("Scrolling"), N_("Keyboard"), N_("Tabs")
     };
     GtkTreeIter iter;
     guint n;
@@ -917,10 +916,12 @@ ProfileGUI *profilegui_open(const char *profile_name, GdkScreen *scrn)
 
     g_hash_table_insert(profilegui_being_edited, g_strdup(profile_name), pg);
 
+#if !VTE_BACKGROUND_DEPRECATED
     profilegui_setup_file_chooser(pg);
     pg->bgimg_drd = drag_receive_setup_dest_widget(
             profilegui_widget(pg, "bgimg_drag_target_vbox"),
             bgimg_drag_data_received, NULL, pg);
+#endif
     profilegui_fill_in_dialog(pg);
     profilegui_connect_handlers(pg);
 
@@ -956,7 +957,9 @@ void profilegui_delete(ProfileGUI * pg)
     UNREF_LOG(g_object_unref(pg->capp.builder));
     dynamic_options_unref(dynopts, pg->profile_name);
     g_free(pg->profile_name);
+#if !VTE_BACKGROUND_DEPRECATED
     drag_receive_data_delete(pg->bgimg_drd);
+#endif
     g_free(pg);
     capplet_dec_windows();
     configlet_unlock_profiles();
